package com.lm.lib.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.gson.Gson;
import com.lm.lib.dto.AlarmMapDto;
import com.lm.lib.entity.FfLocation;
import com.lm.lib.param.*;
import com.lm.lib.service.impl.FfLocationServiceImpl;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

import static java.lang.Math.abs;

@Api(tags = {"大屏页面"})
@Slf4j
@RestController
@RequestMapping("/showData")
public class ShowDataController {

    @Resource(name = "iotpJdbcTemplate")
    JdbcTemplate iotpJdbcTemplate;

    @Resource(name = "qxcasJdbcTemplate")
    JdbcTemplate qxcasJdbcTemplate;

    @Resource(name = "moyuJdbcTemplate")
    JdbcTemplate moyuJdbcTemplate;

    @Resource(name = "ossJdbcTemplate")
    JdbcTemplate ossJdbcTemplate;

    @Resource(name = "safeJdbcTemplate")
    JdbcTemplate safeJdbcTemplate;

//    @Resource
//    FfLocationServiceImpl ffLocationService;


//    @Autowired
//    StoreClient storeClient;
//    StoreApi service = new StoreBindProxy();
//    StoreClient storeClient = new StoreClient(service);


    @ApiOperation(value = "get sn")
    @GetMapping("getSn/{fid}/{sid}")
    public Map<String, Object> getSnForId(@PathVariable String fid, @PathVariable String sid) throws IOException {
        return getSnList(fid, sid);
    }

    private Map<String, Object> getSnList(String fid, String sid) {
        String sql = "select qrcode from py_battery where f_id=" + fid;
        if (null != sid) {
            sql = sql.concat(" and s_id=" + sid);
        }
        List<Map<String, Object>> snData = moyuJdbcTemplate.queryForList(sql);
        List<String> snList = new ArrayList();
        snData.forEach(p -> snList.add(p.get("qrcode").toString()));
        String snString = "\'" + String.join("\',\'", snList) + "\'";
        Map res = new HashMap<String, String>();
        res.put("time", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        res.put("snString", snString);
        res.put("snList", snList);
        return res;
    }

    @ApiOperation(value = "获取美团sn")
    @RequestMapping(value = "/getSn", method = RequestMethod.GET)
    public Map<String, Object> getSn() throws IOException {
        return getSnList("141", null);

    }

    @ApiOperation(value = "获取低电量信息")
    @RequestMapping(value = "/getLowSoc/{fid}/{sid}", method = RequestMethod.GET)
    public Map<String, Object> getLowSoc(@PathVariable String fid, @PathVariable String sid) throws IOException {
        String snString = this.getSnList(fid, sid).get("snString").toString();
        Map<String, Object> res = new HashMap<>();
        String sql = "select product_id as sn, start_time as time,TIMESTAMPDIFF(hour,start_time,now()) as drua, Batpos from all_fault_info where end_time = '0000-00-00 00:00:00' " +
                "and code=58 and product_id in (%s)";
        List<Map<String, Object>> lowSocData;

        try {
            lowSocData = safeJdbcTemplate.queryForList(String.format(sql, snString));
        } catch (EmptyResultDataAccessException e) {
            lowSocData = null;
        }
        if (!ObjectUtils.isEmpty(lowSocData)) {
            List<Object> data = new ArrayList<>();
            lowSocData.forEach(p -> {
                Map<String, Object> thisData = new HashMap<>();
                thisData.put("sn", p.getOrDefault("sn", null));
                thisData.put("time", p.getOrDefault("time", null));
                thisData.put("drua", p.getOrDefault("drua", null));
                data.add(thisData);
            });
            res.put("code", 200);
            res.put("message", "获取成功");
            res.put("data", data);
        } else {
            res.put("code", 500);
            res.put("message", "未获取到数据");
            res.put("data", new ArrayList<>());
        }
        return res;
    }

    @ApiOperation(value = "获取离线信息")
    @RequestMapping(value = "/getOffline/{fid}/{sid}", method = RequestMethod.GET)
    public Map<String, Object> getOffline(@PathVariable String fid, @PathVariable String sid) throws IOException {
        String snString = this.getSnList(fid, sid).get("snString").toString();
        List<String> snList = (List<String>) this.getSnList(fid, sid).get("snList");
        Map<String, Object> res = new HashMap<>();
        String sql = "select product_id as sn, start_time as time,TIMESTAMPDIFF(hour,start_time,now()) as drua, Batpos from all_fault_info where end_time = '0000-00-00 00:00:00' " +
                "and code=59 and product_id in (%s)";
        List<Map<String, Object>> offlineData;

        try {
            offlineData = safeJdbcTemplate.queryForList(String.format(sql, snString));
        } catch (EmptyResultDataAccessException e) {
            offlineData = null;
        }

        List<String> offLineList = new ArrayList<>();
        offlineData.forEach(p -> offLineList.add(p.get("sn").toString()));

        Map<String, Object> thisData = new HashMap<>();
        thisData.put("totalCount", snList.size());
        thisData.put("offLineCount", offlineData.size());
        thisData.put("onLineCount", snList.size() - offlineData.size());
        res.put("code", 200);
        res.put("message", "获取成功");
        res.put("data", thisData);
        return res;
    }

    @ApiOperation(value = "获取故障信息")
    @RequestMapping(value = "/getAlarm/{fid}/{sid}", method = RequestMethod.GET)
    public Map<String, Object> getAlarm(@PathVariable String fid, @PathVariable String sid) throws IOException {
        String snString = this.getSnList(fid, sid).get("snString").toString();
        Map<String, Object> res = new HashMap<>();
        String sql = "select product_id as sn, start_time as time,TIMESTAMPDIFF(hour,start_time,now()) as drua, level, info, advice,Batpos from all_fault_info where end_time = '0000-00-00 00:00:00' " +
                "and code not in (58,59) and product_id in (%s) and level >= 4";
        List<Map<String, Object>> lowSocData;

        try {
            lowSocData = safeJdbcTemplate.queryForList(String.format(sql, snString));
        } catch (EmptyResultDataAccessException e) {
            lowSocData = null;
        }
        if (!ObjectUtils.isEmpty(lowSocData)) {
            List<Object> data = new ArrayList<>();
            lowSocData.forEach(p -> {
                Map<String, Object> thisData = new HashMap<>();
                thisData.put("sn", p.getOrDefault("sn", null));
                thisData.put("time", p.getOrDefault("time", null));
                thisData.put("drua", p.getOrDefault("drua", null));
                thisData.put("level", p.getOrDefault("level", null));
                thisData.put("info", p.getOrDefault("info", null));
                thisData.put("advice", p.getOrDefault("advice", null));

                data.add(thisData);
            });
            res.put("code", 200);
            res.put("message", "获取成功");
            res.put("data", data);
        } else {
            res.put("code", 500);
            res.put("message", "未获取到数据");
            res.put("data", new ArrayList<>());
        }
        return res;
    }

    @ApiOperation(value = "获取gps数据")
    @RequestMapping(value = "/allrealtimeInfo/{fid}/{sid}", method = RequestMethod.GET)
    public Map<String, Object> gpsInfo(@PathVariable String fid, @PathVariable String sid) throws IOException {
        String snString = this.getSnList(fid, sid).get("snString").toString();
        Map<String, Object> res = new HashMap<>();
        String sql = "select t2.latitude, t2.longitude, t1.charge_state, t1.devcode from ff_battery_status t1 left join ff_location t2 on t1.devcode = t2.devcode where t2.devcode in (%s)";
        List<Map<String, Object>> realtimeData;
        List<String> snList = Arrays.asList(snString.replace("'", "").split(","));
        try {
            realtimeData = iotpJdbcTemplate.queryForList(String.format(sql, snString));
        } catch (EmptyResultDataAccessException e) {
            realtimeData = null;
        }
        if (!ObjectUtils.isEmpty(realtimeData)) {
            List<Object> data = new ArrayList<>();
            realtimeData.forEach(p -> {
                Map<String, Object> thisData = new HashMap<>();
                if (ObjectUtils.isEmpty(p.get("latitude")) ||
                        ((abs(Double.parseDouble(p.get("latitude").toString()))) < 0.0001 && (abs(Double.parseDouble(p.get("longitude").toString()))) < 0.0001))
                    return;
                if (!snList.contains(p.get("devcode"))) return;
                thisData.put("latitude", p.getOrDefault("latitude", null));
                thisData.put("longitude", p.getOrDefault("longitude", null));
                thisData.put("devcode", p.getOrDefault("devcode", null));
//                thisData.put("charge_state", p.getOrDefault("charge_state", null));
                data.add(thisData);
            });
            res.put("code", 200);
            res.put("message", "获取成功");
            res.put("data", data);
        } else {
            res.put("code", 500);
            res.put("message", "未获取到数据");
            res.put("data", new ArrayList<>());
        }
        return res;
    }

    @ApiOperation(value = "基本信息")
    @RequestMapping(value = "/baseInfo", method = RequestMethod.GET)
    public RspBaseInfo baseInfo(@ApiParam(name = "查询参数", value = "sn号", required = false) String sn) throws IOException {
        RspBaseInfo rspBaseInfo = new RspBaseInfo();
        List<String> timeList = new ArrayList<>();
        List<Double> voltageMaxList = new ArrayList<>();
        List<Double> voltageMinList = new ArrayList<>();
        List<Double> tempMaxList = new ArrayList<>();
        List<Double> tempMinList = new ArrayList<>();
        List<Double> currentList = new ArrayList<>();
        List<Double> socList = new ArrayList<>();

        HttpEntity httpEntity;
        if (StringUtils.hasLength(sn)) {

//
//            // 必要参数
//            StoreIterable<DataPackage> it = storeClient.load(sn).dataType(12);
//            Date date = new Date();
//            Long fromTs = Safe.getTimestamp(new SimpleDateFormat("yyyy-MM-dd 00:00:00").format(date));
//            Long toTs = Safe.getTimestamp(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(date));
//            it.from(fromTs);
//            it.to(toTs);
//            it.limit(0);


            StringBuffer req = new StringBuffer();
            req.append("http://172.16.126.13/store/load?");
            req.append("dataType=12");
            req.append("&limit=0");
            req.append("&sn=").append(sn);
            Date date = new Date();
            req.append("&from=").append(new SimpleDateFormat("yyyy-MM-dd%2000:00:00").format(date));
            req.append("&to=").append(new SimpleDateFormat("yyyy-MM-dd%20HH:mm:ss").format(date));
            log.info(req.toString());
            HttpGet get = new HttpGet(req.toString());
            httpEntity = HttpClients.createDefault().execute(get).getEntity();
            String s = EntityUtils.toString(httpEntity);
            List<String> dataList = new ArrayList<>();
            if (!s.equals("")) {
                dataList = Arrays.asList(s.split("\n"));
            }

            Gson gson = new Gson();
            for (String p : dataList) {
                Map<String, Object> dataMap = new HashMap<>();
                dataMap = gson.fromJson(p, dataMap.getClass());
                Map<String, Object> info = (Map<String, Object>) dataMap.get("info");
                Map<String, Object> ffBatteryStatus = (Map<String, Object>) dataMap.get("ffBatteryStatus");
                if (ObjectUtils.isEmpty(info) || ObjectUtils.isEmpty(info.get("obdTime")) ||
                        ObjectUtils.isEmpty(ffBatteryStatus) || ObjectUtils.isEmpty(ffBatteryStatus.get("cellVoltageList")) || ObjectUtils.isEmpty(ffBatteryStatus.get("cellTempList"))
                        || ObjectUtils.isEmpty(ffBatteryStatus.get("soc")) || ObjectUtils.isEmpty(ffBatteryStatus.get("current"))) {
                    continue; //如果数据有空的，则跳过该行数据
                } else {
                    timeList.add(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(info.get("obdTime")));
                    List<Double> voltages = (List<Double>) ffBatteryStatus.get("cellVoltageList");
                    voltageMaxList.add(Collections.max(voltages));
                    voltageMinList.add(Collections.min(voltages));

                    List<Double> temps = (List<Double>) ffBatteryStatus.get("cellTempList");
                    tempMaxList.add(Collections.max(temps));
                    tempMinList.add(Collections.min(temps));

                    currentList.add(Double.parseDouble(ffBatteryStatus.get("current").toString()));
                    socList.add(Double.parseDouble(ffBatteryStatus.get("soc").toString()));

                }
            }
            rspBaseInfo.setCurrentList(currentList);
            rspBaseInfo.setSocList(socList);
            rspBaseInfo.setTempMaxList(tempMaxList);
            rspBaseInfo.setTempMinList(tempMinList);
            rspBaseInfo.setTimeList(timeList);
            rspBaseInfo.setVoltageMaxList(voltageMaxList);
            rspBaseInfo.setVoltageMinList(voltageMinList);
            rspBaseInfo.setCode(200);
            rspBaseInfo.setMessage("获取成功");
        } else {
            rspBaseInfo.setCode(500);
            rspBaseInfo.setMessage("未输入sn");
        }


        return rspBaseInfo;
    }

    @ApiOperation(value = "实时信息（位置信息，电池评分，瞬时信息)")
    @RequestMapping(value = "/realtimeInfo", method = RequestMethod.GET)
    public RspRealTimeInfo realtimeInfo(@ApiParam(name = "查询参数", value = "sn号", required = false) String sn) {
        RspRealTimeInfo rspRealTimeInfo = new RspRealTimeInfo();

        if (StringUtils.hasLength(sn)) {
            String sql = "select t1.soh from cellstateestimation_soh t1  where " + "t1.sn='" + sn + "' order by time_st desc limit 1";
            Map<String, Object> sohData;
            try {
                sohData = qxcasJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                sohData = null;
            }

            sql = "select t2.latitude, t2.longitude, t1.soh, t1.soc, t1.current, t1.charge_state, t1.error_level, " +
                    "t1.cell_voltages, t1.max_temp, t1.min_temp, t1.other_temps, t1.status_time from ff_battery_status t1 left join ff_location t2 on t1.devcode = t2.devcode where " +
                    "t1.devcode='" + sn + "' limit 1";
            Map<String, Object> lastData;
            try {
                lastData = iotpJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                lastData = null;
            }
            if (!ObjectUtils.isEmpty(lastData)) {

                rspRealTimeInfo.setLatitude(Double.parseDouble(lastData.getOrDefault("latitude", "").toString()));
                rspRealTimeInfo.setLongitude(Double.parseDouble(lastData.getOrDefault("longitude", "").toString()));

                rspRealTimeInfo.setSoc(lastData.get("soc").toString());
                List<String> voltages = Arrays.asList(((String) lastData.get("cell_voltages")).split(","));
                rspRealTimeInfo.setMaxVolt(Collections.max(voltages));
                rspRealTimeInfo.setCurrent(lastData.get("current").toString());
                rspRealTimeInfo.setMinVolt(Collections.min(voltages));
                Double score;
                Double soh = sohData == null ? Double.parseDouble(lastData.get("soh").toString()) : Double.parseDouble(sohData.get("soh").toString());

                lastData.put("error_level", lastData.get("error_level") == null ? 0 : lastData.get("error_level"));
                Double voltDiff = (600 - (Double.parseDouble(Collections.max(voltages)) - (Double.parseDouble(Collections.min(voltages))))) / 6;
                if (soh.compareTo(100.0) > 0) {
                    soh = 100.0;
                }
                score = (soh * soh * 14.0 / 100.0 +
                        (4 - (Integer) lastData.get("error_level")) * 25 * 5 +
                        1 * 100 * 0.1 +
                        (voltDiff * voltDiff * 6 / 100)) / 25.1;

                rspRealTimeInfo.setScore(score.toString());
                if (((Integer) lastData.get("charge_state")).equals(0)) {
                    rspRealTimeInfo.setStatus("静置");
                }
                if (((Integer) lastData.get("charge_state")).equals(1)) {
                    rspRealTimeInfo.setStatus("快充");
                }
                if (((Integer) lastData.get("charge_state")).equals(2)) {
                    rspRealTimeInfo.setStatus("慢充");
                }
                if (((Integer) lastData.get("charge_state")).equals(3)) {
                    rspRealTimeInfo.setStatus("行车");
                }
                List<String> otherTemps = lastData.get("other_temps") == null ? Arrays.asList("-") : Arrays.asList(((String) lastData.get("other_temps")).split(","));
                rspRealTimeInfo.setConnectorTemp(otherTemps.get(0));
                rspRealTimeInfo.setMaxTemp(lastData.get("max_temp").toString());
                rspRealTimeInfo.setFaultLevel(lastData.get("error_level").toString());
                rspRealTimeInfo.setMinTemp(lastData.get("min_temp").toString());
                rspRealTimeInfo.setStatusTime(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss").format(((LocalDateTime) lastData.get("status_time"))));

                rspRealTimeInfo.setCode(200);
                rspRealTimeInfo.setMessage("获取成功");

            } else {
                rspRealTimeInfo.setCode(500);
                rspRealTimeInfo.setMessage("未查询到实时数据");
            }
        } else {
            rspRealTimeInfo.setCode(500);
            rspRealTimeInfo.setMessage("未输入sn");
        }

        return rspRealTimeInfo;
    }

    @ApiOperation(value = "健康监控")
    @RequestMapping(value = "/healthInfo", method = RequestMethod.GET)
    public RspHealthInfo healthInfo(@ApiParam(name = "查询参数", value = "sn号", required = false) String sn) {
        RspHealthInfo rspHealthInfo = new RspHealthInfo();

        if (StringUtils.hasLength(sn)) {
            String sql = "select t1.soh from cellstateestimation_soh t1  where " + "t1.sn='" + sn + "' order by time_st desc limit 1";
            Map<String, Object> sohData;
            try {
                sohData = qxcasJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                sohData = null;
            }
            sql = "select t1.soh from ff_battery_status t1 where t1.devcode='" + sn + "' limit 1";
            Map<String, Object> lastData;
            try {
                lastData = iotpJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                lastData = null;
            }
            if (!ObjectUtils.isEmpty(sohData) || !ObjectUtils.isEmpty(lastData)) {
                Double soh = sohData == null ? Double.parseDouble(lastData.get("soh").toString()) : Double.parseDouble(sohData.get("soh").toString());
                rspHealthInfo.setSoh(soh.toString());
            } else
                rspHealthInfo.setSoh("-");


            sql = "select cellsoc_diff from cellstateestimation_uniform_socvoltdiff where sn = '" + sn + "' order by time desc limit 1";
            Map<String, Object> consisData;
            try {
                consisData = qxcasJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                consisData = null;
            }
            if (!ObjectUtils.isEmpty(consisData)) {
                if (Double.parseDouble(consisData.get("cellsoc_diff").toString()) < 3) {
                    rspHealthInfo.setConsistency("优");
                } else if (Double.parseDouble(consisData.get("cellsoc_diff").toString()) >= 3 && Double.parseDouble(consisData.get("cellsoc_diff").toString()) < 6) {
                    rspHealthInfo.setConsistency("良");
                } else if (Double.parseDouble(consisData.get("cellsoc_diff").toString()) >= 6 && Double.parseDouble(consisData.get("cellsoc_diff").toString()) < 10) {
                    rspHealthInfo.setConsistency("合格");
                } else if (Double.parseDouble(consisData.get("cellsoc_diff").toString()) >= 10) {
                    rspHealthInfo.setConsistency("差");
                }
            } else
                rspHealthInfo.setConsistency("-");

            sql = "select dsg_phaccum from ff_battery_accum where devcode = '" + sn + "'";
            Map<String, Object> accumData;
            try {
                accumData = iotpJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                accumData = null;
            }
            if (!ObjectUtils.isEmpty(accumData)) {
                if (accumData.get("dsg_phaccum") == null) {
                    rspHealthInfo.setAccumEnergy("-");
                } else {
                    rspHealthInfo.setAccumEnergy(((Double) (Double.parseDouble(accumData.get("dsg_phaccum").toString()) / 1000.0)).toString());
                    // 设备信息解析 电压平台和AH数
                    sql = "select imei from app_device where sn = '" + sn + "'";
                    Map<String, Object> deviceData;
                    try {
                        deviceData = ossJdbcTemplate.queryForMap(sql);
                    } catch (EmptyResultDataAccessException e) {
                        deviceData = null;
                    }
                    if (!ObjectUtils.isEmpty(deviceData)) {
                        Double volt = 0.0;
                        Double crnt;
                        if (deviceData.get("imei").toString().substring(6, 7).equals("4")) {
                            volt = 48.0;
                        } else if (deviceData.get("imei").toString().substring(6, 7).equals("6")) {
                            volt = 60.0;
                        } else if (deviceData.get("imei").toString().substring(6, 7).equals("7")) {
                            volt = 72.0;
                        }
                        crnt = Double.parseDouble(deviceData.get("imei").toString().substring(7, 9));
                        rspHealthInfo.setAccumCycle(((Double) Math.ceil((Double.parseDouble(rspHealthInfo.getAccumEnergy()) / (crnt * volt / 1000.0)))).toString());
                    } else {
                        rspHealthInfo.setAccumCycle("-");
                    }
                }

            } else {
                rspHealthInfo.setAccumEnergy("-");
                rspHealthInfo.setAccumCycle("-");


            }

//            rspHealthInfo.setAccumCycle("-");
//            rspHealthInfo.setAccumEnergy("-");
            rspHealthInfo.setCode(200);
            rspHealthInfo.setMessage("获取成功");
        } else {
            rspHealthInfo.setCode(500);
            rspHealthInfo.setMessage("未输入sn");
        }
        return rspHealthInfo;
    }

    @ApiOperation(value = "报警信息滚动")
    @RequestMapping(value = "/allAlarmInfo", method = RequestMethod.GET)
    public RspAllAlarmInfo allAlarmInfo() {
        RspAllAlarmInfo rspAllAlarmInfo = new RspAllAlarmInfo();

        String sql = "select t1.sn, t1.time, t2.errName, t2.errLevel, t2.treatment from fault_info t1 left join fid_info t2 on t1.fault_code=t2.errCode where t1.time > date_format(now(), '%Y-%m-%d')";
        List<Map<String, Object>> faultData;
        try {
            faultData = qxcasJdbcTemplate.queryForList(sql);
        } catch (EmptyResultDataAccessException e) {
            faultData = null;
        }
        faultData.forEach(p -> {
            AlarmMapDto alarmMap = new AlarmMapDto();
            alarmMap.setInfo(p.get("errName") == null ? null : p.get("errName").toString());
            alarmMap.setLevel(p.get("errLevel") == null ? null : p.get("errLevel").toString());
            alarmMap.setTreatment(p.get("treatment") == null ? null : p.get("treatment").toString());
            alarmMap.setSn(p.get("sn").toString());
            alarmMap.setTime(p.get("time").toString());
            rspAllAlarmInfo.getAlarmList().add(alarmMap);
        });
        rspAllAlarmInfo.setCode(200);
        rspAllAlarmInfo.setMessage("获取成功");

        return rspAllAlarmInfo;
    }

    @ApiOperation(value = "低电量报警信息")
    @RequestMapping(value = "/alarmInfo", method = RequestMethod.GET)
    public RspAlarmInfo alarmInfo(@ApiParam(name = "查询参数", value = "sn号", required = false) String sn) {
        RspAlarmInfo rspAlarmInfo = new RspAlarmInfo();

        if (StringUtils.hasLength(sn)) {
            String sql = "select t1.sn, t1.time, t2.treatment, t2.errName, t2.errLevel from fault_info t1 left join fid_info t2 on t1.fault_code=t2.errCode where " +
                    "t1.sn='" + sn + "'";
            List<Map<String, Object>> faultData;
            try {
                faultData = qxcasJdbcTemplate.queryForList(sql);
            } catch (EmptyResultDataAccessException e) {
                faultData = null;
            }
            if (!ObjectUtils.isEmpty(faultData)) {
                faultData.forEach(p -> {
                    AlarmMapDto alarmMap = new AlarmMapDto();
                    alarmMap.setInfo(p.get("errName") == null ? null : p.get("errName").toString());
                    alarmMap.setLevel(p.get("errLevel") == null ? null : p.get("errLevel").toString());
                    alarmMap.setTreatment(p.get("treatment") == null ? null : p.get("treatment").toString());
                    alarmMap.setSn(p.get("sn").toString());
                    alarmMap.setTime(p.get("time").toString());
                    rspAlarmInfo.getAlarmList().add(alarmMap);
                });
            }
            sql = "select t4.*, t5.f_name  from (select t.*, t3.s_name from " +
                    "(select t1.u_id, t1.u_status, t2.username, t2.mobile,t1.s_id, t1.f_id from py_battery t1 left join py_users t2 on t1.u_id=t2.user_id where qrcode = '" + sn + "') t left join py_site t3 on t3.s_id=t.s_id " +
                    ")t4 left join py_franchisee t5 on t5.f_id=t4.f_id";
            Map<String, Object> userInfo;
            try {
                userInfo = moyuJdbcTemplate.queryForMap(sql);
            } catch (EmptyResultDataAccessException e) {
                userInfo = null;
            }
            if (userInfo != null && !userInfo.get("u_status").toString().equals("0")) {
                rspAlarmInfo.setUserName(userInfo.get("username").toString());
                rspAlarmInfo.setUserPhone(userInfo.get("mobile").toString());
                rspAlarmInfo.setStore(userInfo.get("s_name").toString());
                rspAlarmInfo.setFranchisee(userInfo.get("f_name").toString());
            }
            rspAlarmInfo.setCode(200);
            rspAlarmInfo.setMessage("获取成功");
        } else {
            rspAlarmInfo.setCode(500);
            rspAlarmInfo.setMessage("未输入sn");
        }
        return rspAlarmInfo;
    }
}
