
const url_base = "";

import { Modal } from 'ant-design-vue';
import axios from 'axios'
import router from '../router'
import store from '../store'

/**
 * 检查登录并执行
 * - url
 * - data
 * - success 返回成功
 * - fail    返回失败
 * - error   网络异常
 */
function request(options) {
	var url     = url_base + options.url;
	var data    = options.data    || {};
	var success = options.success || function(){};
	var fail    = options.fail    || function(){};
	var error   = options.error   || function(res){
		console.log(res)
		Modal.error({
			content: "网络错误",
			onOk: function() { fail(res); },
			onCancel: function() { fail(res); },
		})
	};

	axios.post(url, data)
		.then (function(res) {
			// 未登录
			if(res.data.resultCode == -1) {
				store.dispatch('userLoginBean', false).then(function () {
					Modal.confirm({
						title: '登录已失效',
						content: "是否立即重新登录？",
						cancelText: "取消操作",
						okText: "重新登录",
						onOk: function() { router.push('/login'); },
						onCancel: function() { fail(res); }
					})
				})
			}

			// 其他错误
			else if(res.data.resultCode != 0) {
				Modal.warn({
					title: '操作失败',
					content: res.data.message,
					onOk: function() { fail(res); },
					onCancel: function() { fail(res); }
				})
			}

			// 成功
			else {
				success(res);
			}
		})
		.catch(error)
}

/**
 * 容错取值
 * @param {*} val 
 * @param {String} prop 
 * @param {*} def   不经过 show 方法
 * @param {Function} show 
 */
function getSafe(val, prop, def, show) {
	let rec = val;
	prop = prop || '';
	def  = def  || '';
	show = show || function(v) { return v; }

	let props = prop.split(/\./g)
	props.forEach(element => {
		if(element != '' && val != null) {
			val = val[element];
		}
	});

	if(val == null) return def;
	return show(val, rec);
}

export default {
	url_base,
	request,
	getSafe,
}
