import Vue from 'vue'
import App from './App.vue'
import router from './router'
import store from './store'
import axios from 'axios'
import api from './common/api.js'

Vue.config.productionTip = false

/**
 * 页面跳转时检查登录信息
 */
router.beforeEach((to, from, next) => {
	if (to.matched.length > 0 && to.matched[to.matched.length-1].meta.free) {
		// 不需要登录
		next()
	}
	else if (!store.state.userLoginBean) {
		// 从后台获取已登录的信息
		axios.post(api.url_base + 'api/isLogin')
			.then(function(res) {
				// 检查登录结果
				if(res.data.resultCode == 0) {
					// 后台已登录
					store.dispatch('userLoginBean', res.data.content).then(function () {
						next()
					})
				}
				else {
					// 后台未登录
					next('/login')
				}
			})
			.catch(function(res) {
				next('/login')
			})
	}
	else {
		// 已登录
		next()
	}
})

/**
 * 同步菜单
 */
router.afterEach((to, from, next) => {
	if (to.matched.length > 0) {
		var name = to.matched[to.matched.length - 1].name;
		store.commit('menuSelected', name);
	}
})

new Vue({
	router,
	store,
	render: h => h(App)
}).$mount('#app')
