import Vue from 'vue'
import VueRouter from 'vue-router'

Vue.use(VueRouter)

const routes = [
	{
		path: '/login',
		name: 'login',
		component: () => import(/* webpackChunkName: "views" */ '../views/Login.vue'),
		meta: {
			free: true // 不需要登录
		}
	},
	{
		path: '/logout',
		name: 'logout',
		component: () => import(/* webpackChunkName: "views" */ '../views/Logout.vue'),
		meta: {
			free: true // 不需要登录
		}
	},
	{
		// 云监控
		path: '/global',
		name: 'global',
		component: () => import(/* webpackChunkName: "views" */ '../views/GlobalView.vue'),
	},
	{
		// 云监控（带参数）
		path: '/global/:base32',
		name: 'global_view',
		component: () => import(/* webpackChunkName: "views" */ '../views/GlobalView.vue'),
	},
	{
		path: '/',
		name: 'frame',
		component: () => import(/* webpackChunkName: "views" */ '../views/Frame.vue'),
		redirect: 'index',
		meta: {
			free: true // 不需要登录
		},
		children: [
			{
				path: 'index',
				name: 'index',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Index.vue')
			},
			{
				path: 'about',
				name: 'about',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Index.vue'),
			},
			{
				path: 'status',
				name: 'status',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Status.vue'),
				meta: {
					crumb: ['status']
				}
			},
			{
				// 编辑（带参数）
				path: 'status/edit/:id',
				name: 'status_edit',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/status/Edit.vue'),
				meta: {
					crumb: ['status', '编辑']
				}
			},
			{
				// 监控（带参数）
				path: 'status/monitor/:id',
				name: 'status_monitor',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/status/Monitor.vue'),
				meta: {
					crumb: ['status', '监控']
				}
			},
			{
				// 总览（带参数）
				path: 'status/total/:id',
				name: 'status_total',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/status/Total.vue'),
				meta: {
					crumb: ['status', '总览']
				}
			},
			{
				// 定位数据
				path: 'history',
				name: 'history',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/History.vue'),
				meta: {
					crumb: ['history']
				}
			},
			{
				// 定位数据（带参数）
				path: 'history/:mode/:devcode/:limit',
				name: 'history_mode',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/History.vue'),
				meta: {
					crumb: ['status', 'history']
				}
			},
			{
				//电池统计数据
				path: 'batteryAccumLog',
				name: 'batteryAccumLog',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/BatteryAccumLog.vue'),
				meta: {
					crumb: ['batteryAccumLog']
				}
			},
			{
				//电池状态数据
				path: 'batteryStatusLog',
				name: 'batteryStatusLog',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/BatteryStatusLog.vue'),
				meta: {
					crumb: ['batteryStatusLog']
				}
			},
			{
				//调试数据
				path: 'debugLog',
				name: 'debugLog',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/DebugLog.vue'),
				meta: {
					crumb: ['debugLog']
				}
			},
			{
				//上线日志
				path: 'loginLog',
				name: 'loginLog',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/LoginLog.vue'),
				meta: {
					crumb: ['loginLog']
				}
			},
			{
				//站点管理
				path: 'dept',
				name: 'dept',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Dept.vue'),
				meta: {
					crumb: ['dept']
				}
			},
			{
				//新增站点
				path: 'dept/add/:id',
				name: 'dept_add',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/dept/DeptAdd.vue'),
				meta: {
					crumb: ['dept', '新增站点']
				}
			},
			{
				//编辑站点
				path: 'dept/update/:id',
				name: 'dept_update',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/dept/DeptUpdate.vue'),
				meta: {
					crumb: ['dept', '站点编辑']
				}
			},
			{
				//站点详情
				path: 'dept/detail/:id',
				name: 'dept_detail',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/dept/DeptDetail.vue'),
				meta: {
					crumb: ['dept', '站点详情']
				}
			},
			{
				//角色管理
				path: 'role',
				name: 'role',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Role.vue'),
				meta: {
					crumb: ['role']
				}
			},
			{
				//版本管理
				path: 'version',
				name: 'version',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/Version.vue'),
				meta: {
					crumb: ['version']
				}
			},
			{
				//升级管理
				path: 'upgradeTask',
				name: 'upgradeTask',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/UpgradeTask.vue'),
				meta: {
					crumb: ['upgradeTask']
				}
			},
			{
				//升级详情管理
				path: 'upgradeTaskDetail/:id',
				name: 'upgradeTaskDetail_id',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/UpgradeDetail.vue'),
				meta: {
					crumb: ['升级任务详情']
				}
			},
			{
				//升级详情管理
				path: 'upgradeTaskDetail',
				name: 'upgradeTaskDetail',
				component: () => import(/* webpackChunkName: "pages" */ '../views/pages/UpgradeDetail.vue'),
				meta: {
					crumb: ['upgradeTaskDetail']
				}
			},
			{
				// 电池查询
				path: 'batteryQuery',
				name: 'BatteryQuery',
				redirect: 'battery',
				meta: {
					// 不需要登录
					free: true, 
					crumb: ['电池查询']
				}
			}
			
		]
	},
	{
		path: '/battery',
		name: 'battery',
		component: () => import('@/views/pages/BatteryQuery.vue'),
		meta: {
			free: true // 不需要登录
		}
	},
]

const router = new VueRouter({
	routes
})

export default router
